/*     This file is part of KFireSaver.
 *
 *     KFireSaver is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     KFireSaver is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with KFireSaver; if not, write to the Free Software
 *     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 *     Authors:
 *       David Sansome <me@davidsansome.com>
 *       KoRaL <asy@libero.it>
 *
 *     (see the changelog for more information)
 */

#include <qcheckbox.h>
#include <kconfig.h>
#include <klocale.h>

void KFireSaverSetup::init()
{
	readConfig();
}

void KFireSaverSetup::writeConfig()
{
	KConfig config("kfiresaverrc",false,false);
	
	config.writeEntry("enableFlash",flashesBox->isChecked());
	config.writeEntry("enableSparkle",sparkleBox->isChecked());
	
	if ((!redBox->isChecked()) && (!orangeBox->isChecked()) && (!greenBox->isChecked()) && (!blueBox->isChecked())
			&& (!whiteBox->isChecked()) && (!purpleBox->isChecked()) && (!seagreenBox->isChecked()))
		redBox->setChecked(true);

	config.writeEntry("enableRed",redBox->isChecked());
	config.writeEntry("enableOrange",orangeBox->isChecked());
	config.writeEntry("enableGreen",greenBox->isChecked());
	config.writeEntry("enableBlue",blueBox->isChecked());
	config.writeEntry("enableWhite",whiteBox->isChecked());
	config.writeEntry("enablePurple",purpleBox->isChecked());
	config.writeEntry("enableDeepGreen",seagreenBox->isChecked());
	config.writeEntry("enableCombos",allowCombos->isChecked());

	config.writeEntry("fireworksFrequency",fireworkFrequencySlider->value());

	config.writeEntry("enableBottomFire",bottomFireBox->isChecked());
	config.writeEntry("bottomFireColour",bottomFireColourList->currentItem());

	config.writeEntry("enableTux",tuxBox->isChecked());
	config.writeEntry("enableKdeLogo",kdeBox->isChecked());
	
	config.writeEntry("logoFrequency",logosFrequencySlider->value());
	
	config.writeEntry("enableTrails",trailsBox->isChecked());
	
	accept();
}

void KFireSaverSetup::readConfig()
{
	KConfig config("kfiresaverrc",true,false);

	flashesBox->setChecked(config.readBoolEntry("enableFlash",false));
	sparkleBox->setChecked(config.readBoolEntry("enableSparkle",true));

	redBox->setChecked(config.readBoolEntry("enableRed",true));
	orangeBox->setChecked(config.readBoolEntry("enableOrange",true));
	greenBox->setChecked(config.readBoolEntry("enableGreen",true));
	blueBox->setChecked(config.readBoolEntry("enableBlue",true));
	whiteBox->setChecked(config.readBoolEntry("enableWhite",true));
	purpleBox->setChecked(config.readBoolEntry("enablePurple",true));
	seagreenBox->setChecked(config.readBoolEntry("enableDeepGreen",true));
	allowCombos->setChecked(config.readBoolEntry("enableCombos",true));

	fireworkFrequencySlider->setValue(config.readNumEntry("fireworksFrequency",5));

	bottomFireBox->setChecked(config.readBoolEntry("enableBottomFire",true));
	bottomFireColourList->setCurrentItem(config.readNumEntry("bottomFireColour",1));

	tuxBox->setChecked(config.readBoolEntry("enableTux",true));
	kdeBox->setChecked(config.readBoolEntry("enableKdeLogo",false));

	logosFrequencySlider->setValue(config.readNumEntry("logoFrequency",5));
	
	trailsBox->setChecked(config.readBoolEntry("enableTrails",true));
}
